How do I set up the example project myself?
===========================================

This section is a step by step tutorial how to create the `my_project` project contained in the example folder yourself.

.. toctree::
    :caption: Contents:

    project-creation
    app-creation
    adding-data
    class-interface
    dependencies
    views
